from typing import Literal

TransitionDelay = Literal[
    '0',
    '75',
    '100',
    '150',
    '200',
    '300',
    '500',
    '700',
    '1000',
]
